<?php
declare(strict_types=1);

namespace Drupal\membership\Entity\Member\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for Member forms.
 *
 * @ingroup membership
 */
class MemberForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    // Load the member_id from the URL.
    $route_match = \Drupal::service('current_route_match');
    $member_id = $route_match->getParameter('membership');

    if ($this->operation == 'edit') {
      $form['#title'] = $this->t('Edit member');
    }

    if ($this->operation == 'add') {
      $form['#title'] = $this->t('Add a new member');

      $form['member_id'] = [
        '#type' => 'hidden',
        '#default_value' => $member_id,
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    /* @var \Drupal\membership\Entity\Member\MemberInterface $member */
    $member = $this->entity;
    $status = parent::save($form, $form_state);
    $form_state->setRedirect('entity.membership_member.collection', ['membership' => $member->memberId()]);
  }
}
