<?php
declare(strict_types=1);

namespace Drupal\membership\Entity\Member;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider;
use Symfony\Component\Routing\Route;

/**
 * Provides routes for Member entities.
 *
 * @see \Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider
 */
class MemberHtmlRouteProvider extends DefaultHtmlRouteProvider {

  /**
   * {@inheritdoc}
   */
  protected function getEditFormRoute(EntityTypeInterface $entity_type) {
    if ($route = parent::getEditFormRoute($entity_type)) {
      $this->setDefaultRouteParameters($route);
      return $route;
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function getDeleteFormRoute(EntityTypeInterface $entity_type) {
    if ($route = parent::getDeleteFormRoute($entity_type)) {
      $this->setDefaultRouteParameters($route);
      return $route;
    }
  }

  /**
   * Set the default URL parameters for Member routes.
   *
   * Most membership term URLs take the form
   * /membership/{membership}/member/{membership_member}/...
   *
   * @param \Symfony\Component\Routing\Route $route
   *   The member route.
   */
  protected function setDefaultRouteParameters(Route &$route) {
    $route->setOption('parameters', [
      'membership' => ['type' => 'entity:membership'],
      'membership_member' => ['type' => 'entity:membership_member'],
    ]);
  }
}
