<?php
declare(strict_types=1);

namespace Drupal\membership\Entity\Member;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Url;

/**
 * Defines a class to build a listing of Members.
 *
 * @ingroup membership
 */
class MemberListBuilder extends EntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function getEntityIds() {
    $route_match = \Drupal::service('current_route_match');
    $member_id = $route_match->getParameter('membership');

    $query = $this->getStorage()
      ->getQuery()
      ->condition('member_id', $member_id);

    if ($this->limit) {
      $query->pager($this->limit);
    }

    return $query->execute();
  }

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['member'] = $this->t('Member');
    $header['roles'] = $this->t('Roles');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /* @var $entity \Drupal\membership\Entity\Member\MemberInterface */
    $row['member'] = $entity->accountName(TRUE);
    $row['roles'] = $entity->roles();
    return $row + parent::buildRow($entity);
  }

  /**
   * @inheritDoc
   */
  public function render() {
    $build = parent::render();
    $route_match = \Drupal::service('current_route_match');
    $member_id = $route_match->getParameter('membership');
    $build['table']['#empty'] = $this->t('There are no Members yet. <a href=":link">Add a new Member</a>', [
      ':link' => Url::fromRoute('entity.membership_member.add_form', ['membership' => $member_id])->toString(),
    ]);
    return $build;
  }

  /**
   * @inheritDoc
   */
  protected function getTitle() {
    return $this->t('Members');
  }

}
