<?php
declare(strict_types=1);

namespace Drupal\membership\Entity;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Defines a class to build a listing of Membership entities.
 *
 * @ingroup membership
 */
class MembershipListBuilder extends EntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['id'] = $this->t('Membership ID');
    $header['name'] = $this->t('Name');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /* @var $entity \Drupal\membership\Entity\Membership */
    $row['id'] = Link::createFromRoute(
      $entity->id(),
      'entity.membership.canonical',
      ['membership' => $entity->id()]
    );
    $row['name'] = $entity->label();

    return $row + parent::buildRow($entity);
  }

  /**
   * @inheritDoc
   */
  public function render() {
    $build = parent::render();
    $build['table']['#empty'] = $this->t('There are no Memberships yet. <a href=":link">Add a Membership</a>', [
      ':link' => Url::fromRoute('entity.membership.add_page')->toString(),
    ]);
    return $build;
  }

  /**
   * @inheritDoc
   */
  protected function getTitle() {
    return $this->t('Memberships');
  }

}
