<?php

namespace Drupal\membership\Entity\MembershipOption;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the membership option entity.
 *
 * @ConfigEntityType(
 *   id = "membership_option",
 *   label = @Translation("Membership Option"),
 *   label_collection = @Translation("Membership Options"),
 *   label_singular = @Translation("membership option"),
 *   label_plural = @Translation("membership options"),
 *   label_count = @PluralTranslation(
 *     singular = "@count membership option",
 *     plural = "@count membership options",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\membership\Entity\MembershipOption\MembershipOptionListBuilder",
 *     "storage" = "Drupal\Core\Config\Entity\ConfigEntityStorage",
 *     "form" = {
 *       "add" = "Drupal\membership\Entity\MembershipOption\Form\MembershipOptionForm",
 *       "edit" = "Drupal\membership\Entity\MembershipOption\Form\MembershipOptionForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm",
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider"
 *     },
 *   },
 *   admin_permission = "administer memberships",
 *   config_prefix = "option",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *     "status" = "status",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "status",
 *     "settings",
 *   },
 *   links = {
 *     "collection" = "/admin/memberships/config/options",
 *     "add-form" = "/admin/memberships/config/options/add",
 *     "edit-form" = "/admin/membership/config/options/{membership_option}/edit",
 *     "delete-form" = "/admin/memberships/config/options/{membership_option}/delete",
 *   }
 * )
 */
class MembershipOption extends ConfigEntityBase implements MembershipOptionInterface {

  /**
   * The membership option ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The membership option label.
   *
   * @var string
   */
  protected $label;

  /**
   * The membership option settings.
   *
   * @var mixed[]
   */
  protected $settings = [];

  /**
   * {@inheritdoc}
   */
  public function getSettings() {
    return $this->settings;
  }

  /**
   * {@inheritdoc}
   */
  public function setSettings($settings) {
    $this->settings = $settings;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getSetting($key) {
    if (array_key_exists($key, $this->settings)) {
      return $this->settings[$key];
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function setSetting($key, $value) {
    $this->settings[$key] = $value;
    return $this;
  }

}
