<?php

namespace Drupal\membership\Entity\MembershipOption;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

/**
 * Provides a listing of Membership options.
 */
class MembershipOptionListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['label'] = $this->t('Membership Option');
    $header['status'] = $this->t('Status');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['label'] = $this->t('@label (@id)', [
      '@label' => $entity->label(),
      '@id' => $entity->id(),
    ]);
    $row['status'] = $entity->status() ? $this->t('Enabled') : $this->t('Disabled');
    return $row + parent::buildRow($entity);
  }

  /**
   * @inheritDoc
   */
  public function render() {
    $build = parent::render();
    $build['table']['#empty'] = $this->t('There are no Membership options defined yet. <a href=":link">Add a new membership option.</a>', [
      ':link' => Url::fromRoute('entity.membership_option.add_form')->toString(),
    ]);
    return $build;
  }

  /**
   * @inheritDoc
   */
  protected function getTitle() {
    return $this->t('Membership Options');
  }
}
