<?php
declare(strict_types=1);

namespace Drupal\membership\Entity\MembershipTerm;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Url;

/**
 * Defines a class to build a listing of Membership Terms.
 *
 * @ingroup membership
 */
class MembershipTermListBuilder extends EntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function getEntityIds() {
    $route_match = \Drupal::service('current_route_match');
    $member_id = $route_match->getParameter('membership');

    $query = $this->getStorage()
      ->getQuery()
      ->condition('member_id', $member_id);

    if ($this->limit) {
      $query->pager($this->limit);
    }

    return $query->execute();
  }

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['term_length'] = $this->t('Term Length');
    $header['start'] = $this->t('Start Date');
    $header['end'] = $this->t('End Date');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /* @var $entity \Drupal\membership\Entity\MembershipTerm\MembershipTermInterface */

    $output = $entity->term()->view();

    $row['term_length'] = $entity->term()->term_length;
    $row['start'] = ['data' => $output[0]['start_date']];
    $row['end'] = $entity->isLifetime() ? 'N/A' : ['data' => $output[0]['end_date']];
    return $row + parent::buildRow($entity);
  }

  /**
   * @inheritDoc
   */
  public function render() {
    $build = parent::render();
    $route_match = \Drupal::service('current_route_match');
    $member_id = $route_match->getParameter('membership');
    $build['table']['#empty'] = $this->t('There are no Memberships Terms yet. <a href=":link">Add a new Term</a>', [
      ':link' => Url::fromRoute('entity.membership_term.add_form', ['membership' => $member_id])->toString(),
    ]);
    return $build;
  }

  /**
   * @inheritDoc
   */
  protected function getTitle() {
    return $this->t('Membership History');
  }

}
