<?php

namespace Drupal\membership\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for Membership edit forms.
 *
 * @ingroup membership
 */
class MembershipForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    if ($this->entity->isNew()) {

      // Add the primary account to the new membership form. For existing
      // memberships, accounts can be managed from the
      // /membership/<member_id>/history page.
      $form['account'] = [
        '#type' => 'entity_autocomplete',
        '#title' => $this->t('Primary Member'),
        '#description' => $this->t('Select an existing user account or click "New User"'),
        '#target_type' => 'user',
        '#field_suffix' => '<a href="/admin/user/add" class="button">New User</a>',
      ];

      // Add the initial membership term. For existing memberships, terms
      // can be managed from the /membership/<member_id>/history page
      $form['term'] = [
        '#type' => 'datetime',
        '#title' => $this->t('Membership Start Date'),
        '#description' => $this->t('Enter the membership start date'),
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $membership = $this->entity;
    $membership->setNewRevision();
    $status = parent::save($form, $form_state);

    $params = ['%member_id' => $membership->getMemberID()];
    $messages = [
      SAVED_NEW => $this->t('Added Membership %member_id.', $params),
      'default' => $this->t('Saved Membership %member_id.', $params),
    ];
    if (isset($messages[$status])) {
      $this->messenger()->addMessage($messages[$status]);
    }
    else {
      $this->messenger()->addMessage($messages['default']);
    }

    $form_state->setRedirect('entity.membership.canonical', ['membership' => $membership->id()]);
  }
}
