<?php
declare(strict_types=1);

namespace Drupal\membership;

use Drupal\workflows\StateInterface;

/**
 * An object representing a membership state.
 */
class MembershipState implements StateInterface {

  /**
   * The vanilla state object from the Workflow module.
   *
   * @var \Drupal\workflows\StateInterface
   */
  protected $state;

  /**
   * If the membership is considered active in this state.
   *
   * @var bool
   */
  protected $active;


  /**
   * Membership constructor.
   *
   * Decorates state objects to add methods to determine if a membership should
   * be considered active.
   *
   * @param \Drupal\workflows\StateInterface $state
   *   The vanilla state object from the Workflow module.
   * @param bool $active
   *   (optional) TRUE if memberships should be active if in this state, FALSE
   *   if not. Defaults to FALSE.
   */
  public function __construct(StateInterface $state, $active = FALSE) {
    $this->state = $state;
    $this->active = $active;
  }

  /**
   * Determines if membership is active.
   *
   * @return bool
   */
  public function isActive() {
    return $this->active;
  }

  /**
   * {@inheritdoc}
   */
  public function id() {
    return $this->state->id();
  }

  /**
   * {@inheritdoc}
   */
  public function label() {
    return $this->state->label();
  }

  /**
   * {@inheritdoc}
   */
  public function weight() {
    return $this->state->weight();
  }

  /**
   * {@inheritdoc}
   */
  public function canTransitionTo($to_state_id) {
    return $this->state->canTransitionTo($to_state_id);
  }

  /**
   * {@inheritdoc}
   */
  public function getTransitionTo($to_state_id) {
    return $this->state->getTransitionTo($to_state_id);
  }

  /**
   * {@inheritdoc}
   */
  public function getTransitions() {
    return $this->state->getTransitions();
  }

}
