<?php
declare(strict_types=1);

namespace Drupal\membership\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Plugin implementation of the 'membership_workflow' field type.
 *
 * This is a custom field type that connects a workflow configuration entity
 * to a Membership term entity.
 *
 * @FieldType(
 *   id = "membership_workflow",
 *   label = @Translation("Membership Workflow"),
 *   description = @Translation("Connection to a Membership Workflow Type."),
 *   no_ui = "true"
 * )
 */
class MembershipWorkflowItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['value'] = DataDefinition::create('string')
      ->setLabel(t('Current State'))
      ->setRequired(TRUE);
    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    $schema['columns']['value'] = [
      'description' => 'The current workflow state.',
      'type' => 'varchar',
      'length' => 255,
    ];
    return $schema;
  }

}
